# CDEK Python SDK v2

<p align="center">
  <a href="https://github.com/xxp-odoo-erp/cdek/actions/workflows/ci.yml?query=branch%3Amain">
    <img src="https://img.shields.io/github/actions/workflow/status/xxp-odoo-erp/cdek/ci.yml?branch=main&label=CI&logo=github&style=flat-square" alt="CI Status" >
  </a>
  <a href="https://cdek.readthedocs.io/ru/latest/">
    <img src="https://img.shields.io/readthedocs/cdek.svg?logo=read-the-docs&logoColor=fff&style=flat-square" alt="Documentation Status">
  </a>
  <a href="https://codecov.io/gh/xxp-odoo-erp/cdek">
    <img src="https://img.shields.io/codecov/c/github/xxp-odoo-erp/cdek.svg?logo=codecov&logoColor=fff&style=flat-square" alt="Test coverage percentage">
  </a>
</p>
<p align="center">
  <a href="https://github.com/astral-sh/uv">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/uv/main/assets/badge/v0.json" alt="uv">
  </a>
  <a href="https://github.com/astral-sh/ruff">
    <img src="https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/astral-sh/ruff/main/assets/badge/v2.json" alt="Ruff">
  </a>
  <a href="https://github.com/pre-commit/pre-commit">
    <img src="https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white&style=flat-square" alt="pre-commit">
  </a>
</p>
<p align="center">
  <a href="https://pypi.org/project/cdek/">
    <img src="https://img.shields.io/pypi/v/cdek.svg?logo=python&logoColor=fff&style=flat-square" alt="PyPI Version">
  </a>
  <img src="https://img.shields.io/pypi/pyversions/cdek.svg?style=flat-square&logo=python&amp;logoColor=fff" alt="Supported Python versions">
  <img src="https://img.shields.io/pypi/l/cdek.svg?style=flat-square" alt="License">
</p>

---

**Документация**: <a href="https://cdek.readthedocs.io/ru/latest/" target="_blank">https://cdek.readthedocs.io </a>

**Исходный код**: <a href="https://github.com/xxp-odoo-erp/cdek" target="_blank">https://github.com/xxp-odoo-erp/cdek </a>

---

CDEK Python SDK упрощает интеграцию с API СДЭК версии 2.0

## Установка

Установите пакет через pip (или ваш любимый менеджер пакетов):

`pip install cdek`

## Участники ✨

Спасибо этим замечательным людям ([ключ эмодзи](https://allcontributors.org/docs/en/emoji-key)):

<!-- prettier-ignore-start -->
<!-- ALL-CONTRIBUTORS-LIST:START - Do not remove or modify this section -->
<!-- markdownlint-disable -->
<!-- markdownlint-enable -->
<!-- ALL-CONTRIBUTORS-LIST:END -->
<!-- prettier-ignore-end -->

Этот проект следует спецификации [all-contributors](https://github.com/all-contributors/all-contributors). Приветствуются любые виды вклада!

## Благодарности

[![Copier](https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/copier-org/copier/master/img/badge/badge-grayscale-inverted-border-orange.json)](https://github.com/copier-org/copier)

Этот пакет был создан с помощью
[Copier](https://copier.readthedocs.io/) и шаблона проекта
[browniebroke/pypackage-template](https://github.com/browniebroke/pypackage-template).
